

set -ex



test -f $PREFIX/lib/libharfbuzz-icu.dylib
test -f $PREFIX/lib/libharfbuzz.dylib
test -f $PREFIX/include/harfbuzz/hb-ft.h
conda inspect linkages -p $PREFIX $PKG_NAME
conda inspect objects -p $PREFIX $PKG_NAME
exit 0
